# import the data from the file "taskus a.csv" and save a copy that won't be modified
taskusdata <- read.csv("taskus b.csv")
taskusdataoriginal <- taskusdata

# rename the columns to make it easier to work with
colnames(taskusdata) <- c("article", "rating", "adjusted.rating", "notes", "link", "text")

# load a list of regex patterns for known mirrors and other sites that copy Wikipedia content, aka "badlinks"
badlinks <- readLines("badlinks.txt")

# replace every badlink match with "falsepositive"
for(i in badlinks){
	taskusdata$link <- sub(i, "falsepositive", taskusdata$link)
}

# remove the falsepositive lines that are not the main entry for an article revision (ie, have nothing in the "article" column)
taskusdata <- taskusdata[taskusdata$article !="" | taskusdata$link != "falsepositive",]

# if there is only one remaining entry for an article revision, and the link is a falsepositive, then set the adjusted rating to 1 (no plagiarism)

for(i in 1:(length(taskusdata$article)-1)){
	if(taskusdata$article[i] != "" & taskusdata$link[i] == "falsepositive" & taskusdata$article[i+1] != "") {
		taskusdata$adjusted.rating[i] <- 1
	}
}
# at this point, we can export taskusdata and put it back into a spreadsheet, and continue adding manually updated ratings and improving the list of badlinks as we go. sending the data back through this script periodically will help speed things along by trimming out cruft.

# select all the original taskus ratings that are valid scores, along with the corresponding adjusted ratings
initialratings <- subset(taskusdata[,2:3], rating %in% c(1,2,3) )

# substitute in all the adjusted ratings to get "updatedratings"
updatedratings <- initialratings
for(i in 1:length(initialratings$rating)){
        if(!is.na(initialratings$adjusted.rating[i])){
               updatedratings$rating[i] <- initialratings$adjusted.rating[i]
        }
}

# remove the excess levels
updatedratings$rating <- factor(updatedratings$rating)

# now let's plot some data!
library(ggplot2)

# create a ggplot object with our rating data
p <- ggplot(updatedratings, aes(x = rating))

# make some labels for the different levels of plagiarism, and a colour scheme to go with them
ratingscale <- c("fine","close paraphrasing","blatant copyvio")
colourscheme <- c("green", "orange", "red")

# now use the scale to label the plot object, and apply the colour scheme. NOTE: use factors() to fix the scale problems
p <- p + scale_x_discrete(labels = ratingscale) + scale_fill_manual(values = colourscheme)

# make it a histogram
p <- p + geom_histogram(binwidth = 0.5, origin = -0.25, aes(fill = factor(rating)), colour = "black")

print(p)

